@@ -1,10 +1,12 @@
 import os
 import time
 import unittest
-from unittest import TestCase, skipIf
+from unittest import TestCase, skipIf, skipUnless
 
 import mongomock
 import mongomock.gridfs
+from mongomock import helpers
+from packaging import version
 from six import text_type
 
 try:
@@ -21,13 +23,12 @@ try:
 
     import pymongo
     from pymongo import MongoClient as PymongoClient
-    _HAVE_PYMONGO = True
 except ImportError:
-    _HAVE_PYMONGO = False
+    ...
 
 
-@skipIf(not _HAVE_PYMONGO, 'pymongo not installed')
-@skipIf(not _HAVE_GRIDFS, 'gridfs not installed')
+@skipUnless(helpers.HAVE_PYMONGO, 'pymongo not installed')
+@skipUnless(_HAVE_GRIDFS, 'gridfs not installed')
 @skipIf(os.getenv('NO_LOCAL_MONGO'), 'No local Mongo server running')
 class GridFsTest(TestCase):
 
@@ -81,7 +82,7 @@ class GridFsTest(TestCase):
         self.assertFalse(self.fake_gridfs.exists(fid))
         self.assertFalse(self.get_fake_file(fid) is not None)
         # All the chunks got removed
-        self.assertEqual(0, self.fake_conn[self.db_name].fs.chunks.find({}).count())
+        self.assertEqual(0, self.fake_conn[self.db_name].fs.chunks.count_documents({}))
 
     def test__delete_exists_big(self):
         fid = self.fake_gridfs.put(GenFile(500000))
@@ -91,7 +92,7 @@ class GridFsTest(TestCase):
         self.assertFalse(self.fake_gridfs.exists(fid))
         self.assertFalse(self.get_fake_file(fid) is not None)
         # All the chunks got removed
-        self.assertEqual(0, self.fake_conn[self.db_name].fs.chunks.find({}).count())
+        self.assertEqual(0, self.fake_conn[self.db_name].fs.chunks.count_documents({}))
 
     def test__delete_no_file(self):
         # Just making sure we don't crash
@@ -105,12 +106,12 @@ class GridFsTest(TestCase):
         names = ['one', 'two', 'three', 'four']
         names_no_two = [x for x in names if x != 'two']
         for x in self.fake_gridfs.list():
-            self.assertTrue(x in names)
+            self.assertIn(x, names)
 
         self.fake_gridfs.delete(fids[1])
 
         for x in self.fake_gridfs.list():
-            self.assertTrue(x in names_no_two)
+            self.assertIn(x, names_no_two)
 
         three_file = self.get_fake_file(fids[2])
         self.assertEqual('three', three_file['filename'])
@@ -128,7 +129,7 @@ class GridFsTest(TestCase):
         c = self.fake_gridfs.find({'filename': 'a'}).sort('uploadDate', -1)
         should_be_fid3 = c.next()
         should_be_fid0 = c.next()
-        self.assertEqual(2, c.count())
+        self.assertFalse(c.alive)
 
         self.assertEqual(fids[3], should_be_fid3._id)
         self.assertEqual(fids[0], should_be_fid0._id)
@@ -139,7 +140,10 @@ class GridFsTest(TestCase):
             self.fake_gridfs.put(GenFile(2, 3), _id='12345')
 
     def assertSameFile(self, real, fake, max_delta_seconds=1):
-        self.assertEqual(real['md5'], fake['md5'])
+        # https://pymongo.readthedocs.io/en/stable/migrate-to-pymongo4.html#disable-md5-parameter-is-removed
+        if helpers.PYMONGO_VERSION < version.parse('4.0'):
+            self.assertEqual(real['md5'], fake['md5'])
+
         self.assertEqual(real['length'], fake['length'])
         self.assertEqual(real['chunkSize'], fake['chunkSize'])
         self.assertLessEqual(
